This function is used to generate CI estimates at given intervals. It is currently used for plotting in BayClump.
cal.ci(data, from, to, length.out = 100)A data.frame or list of data.frames with the
confidence interval for a given model in a given range
of X.
A data.frame with two columns named as beta and alpha.
This should be the result of bootstrapping or the posterior distribution
for a given calibration set.
the lower limit in x.
the upper limit in x.
the number of breaks.