rec.prior: Generate a dataset reflecting the priors used to run the analyses
Description
Generate a dataset reflecting the priors used to run the analyses
Usage
rec.prior(prior, n = 1000)
Value
A data.frame with prior distributions.
Arguments
- prior
Informative or not
- n
number of observations to simulate